
from .vegetation_dynamics import Vegetation


__all__ = ["Vegetation"]
